%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


% Sample driver script for C. elegans vulval development with GESSA

% erase the current matlab workspace
clear all;

% load all functions and classes from the Hybrid Model used for this simulation
addpath('Classes/');
addpath('Functions/');
addpath('../HybridModel/Classes/');
addpath('../HybridModel/Functions/');

% specified the centralized parameter file for the C. elegans simulation 
parametersFile = 'Data/WT_3cells/simulationParameters.txt';

% run the central hybrid model for the C elegans wild type vulval
% development
[avgHistory, allOrgHistory, output, startTime, endTime] = ...
    driveHybridModel(parametersFile);

% unzip files saved from central simlation to append diagnostics to archive
unzip(sprintf('%s.zip', output));

resultsDir = fullfile(output,'SimulationResults');

mkdir(resultsDir);

% save snapshots for EGL17 every half hour
speciesFile = sprintf('%s/SimulationResults/EGL17_Numbers.txt', output);
speciesPerOrg( allOrgHistory, {'P5.p', 'P6.p', 'P7.p'},{'cytoplasm_EGL17'}, ...
    {'TT_Specie'},startTime, endTime, 1800, speciesFile)


% plot singnaling proteins from P6.p cell on one plot
RASPathwayH = figure;
plotSpeciesHistory(avgHistory, 'actprot', ...
    {'SEM5','SOS1','LET60','LIN45','MEK2','SUR1'}, ...
    {'c.','r.','k.','g.','m.','b.'}, true, true, ...
    {' ', ' ', ' ',' ', ' ', ' '}, [false,true,false]);
%saveas(RASPathwayH, sprintf('%s/SimulationResults/RASPathway.eps', output), ...
%    'eps');

% plot mRNA's and corresponding proteins
MRNAH = figure;
plotmRNA( avgHistory,'P6.p')
%saveas(MRNAH, sprintf('%s/SimulationResults/mRNA.eps', output), 'eps');

% rezip including diagnostics from simulation in archive
zip(output,sprintf('%s/*',output));
rmdir(output,'s')
