%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


classdef CelegansPlotter
    % Class for plotting C.elegans species
    
    properties(GetAccess = private, Constant = true)
        LineColors = {'k', 'r', 'c'} % P6.p is red
    end
    
     methods (Static = true, Access = public)
              
        function plotScaffold(orgHistory)
            figure;
            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'actprot', {'Let60'}, ...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Active Let-60');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'actprot', {'Lin45'}, ...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Active Lin-45');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'actprot', {'Mek2'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Active Mek-2');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'actprot', {'Sur1'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Active Sur-1');
            

        end
        
        function plotReducedCElegans(orgHistory)
            figure;
            
            subplot(2,2,1);
             plotSpeciesHistory(orgHistory, 'extsig', {'Lin3'}, ...
                 {'-'}, true, true, CelegansPlotter.LineColors);
            title('Evolution of LIN3');            
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'actprot', {'Sur1'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of Sur1');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LAG2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LAG2');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'repressor',...
                {'LIP1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of the repressors');

        end
        
        function plotSignalingProteins(orgHistory)
            figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'actrecept', {'Let23'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LET23')

            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'actprot', {'Sem5'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of Sem5')

            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'actprot', {'Lin45'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of Lin45')

            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'actprot', {'MEK2'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of MEK2')

            
        end
        
        function plotWNTPathway(orgHistory)
            figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'actprot',...
                {'SYS1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of SYS1');            
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'extsig',...
                {'EGL20'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of EGL20');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'extsig',...
                {'MOM2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of MOM2');            
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'actprot',...
                {'LIN18'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN18');        
        end
        
        function plotTTSpeciesLIN39(orgHistory)
            figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LIN1_LIN31'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN1+LIN31');
           
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_UP1_P'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP1+P in nucleus');
             
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LIN1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN1');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LIN31'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN31'); 
            
            figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlin39_LIN31'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNAlin39+LIN31');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlin39_LIN31_RNAP'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNAlin39+LIN31+RNAP');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_RNAP_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of RNAP producing mRNA lin39');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lin39 in nucleus'); 
            
           figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_mRNA_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA LIN39 in cytoplasm');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_mRNA_lin39_initiated'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lin39 + Ribo'); 
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_transl_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of Ribo producing LIN39');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN39 in cytoplasm');            
            
        end
        
        function plotTTSpeciesLAG2(orgHistory)
            figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN39 in nucleus');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_CEH20'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of CEH20'); 
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_CEH20_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of CEH20+LIN39');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNA lag2'); 

           figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlag2_CEH20_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNAlag2+CEH20+LIN39'); 
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlag2_CEH20_LIN39_RNAP'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNAlag2+CEH20+LIN39+RNAP'); 
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_RNAP_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of RNAP producing mRNA lag2');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lag2 in nucleus');
            
           figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_mRNA_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lag2 in cytoplasm');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_mRNA_lag2_initiated'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lag2 + Ribo');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_transl_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of Ribo producing LAG2'); 
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LAG2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LAG2'); 

        end
        
        function plotTTSpeciesLIP1(orgHistory)
            figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_NICD'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of NICD in nucleus');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LAG1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LAG1'); 
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_NICD_LAG1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of NICD+LAG1');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNA lip1'); 

           figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlip1_NICD_LAG1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNAlip1+NICD+LAG1'); 
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_DNAlip1_NICD_LAG1_RNAP'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of DNAlip1+NICD+LAG1+RNAP'); 
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_RNAP_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of RNAP producing mRNA lip1');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lip1 in nucleus');
            
           figure;            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_mRNA_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lip1 in cytoplasm');
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_mRNA_lip1_initiated'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lip1 + Ribo');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_transl_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of Ribo producing LIP1'); 
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LIP1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIP1'); 

        end
        
        function plotRNAPelong(orgHistory)
            figure;            
            subplot(3,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_RNAP_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of RNAP producing mRNA lin39');
            
            subplot(3,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lin39 in nucleus'); 
           
            subplot(3,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_RNAP_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of RNAP producing mRNA lag2');
            
            subplot(3,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lag2 in nucleus'); 
            
            subplot(3,2,5);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_RNAP_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of RNAP producing mRNA lip1');
            
            subplot(3,2,6);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA lip1 in nucleus');
        end
       
        function plotmRNA(orgHistory)
            figure;
            
            subplot(3,2,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lin39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA LIN39 in nucleus');
            
            subplot(3,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN39 in cytoplasm');            
            
            subplot(3,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lag2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA LAG2 in nucleus');
            
            subplot(3,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LAG2'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LAG2 in cytoplasm');            
            
            subplot(3,2,5);
             plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_mRNA_lip1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of mRNA LIP1 in nucleus');
            
            subplot(3,2,6);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LIP1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIP1 in cytoplasm');            
        end
       
        function plotUP1(orgHistory)
            figure;
            
            subplot(2,2,1);
            plotSpeciesHistory(orgHistory, 'prot', {'UP1'},...
                {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP1 in inactive proteins');            
            
            subplot(2,2,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_UP1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP1 in cytoplasm');
            
            subplot(2,2,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_UP1_P'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP1+P in nucleus');
            
            subplot(2,2,4);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_UP1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP in nucleus'); 
        end
        
        function plotUP1_TT(orgHistory)
            figure;
            
            subplot(3,1,1);
            plotSpeciesHistory(orgHistory, 'prot', {'UP1'}, {'-'},...
                true, false, CelegansPlotter.LineColors);
            title('UP1 inactive in nucleus');
            
            subplot(3,1,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_UP1_P'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP1+P in nucleus'); 
            
            subplot(3,1,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_UP1'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of UP1 in nucleus');
            
         end
             
        function plotLIN39(orgHistory)
            figure;            
            subplot(3,1,1);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'cytoplasm_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN39 in cytoplasm');   
            
            subplot(3,1,2);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN39 in nucleus in LIN39 species');   

            subplot(3,1,3);
            plotSpeciesHistory(orgHistory, 'TT_Specie',...
                {'nucleus_LIN39'}, {'-'}, true, false, CelegansPlotter.LineColors);
            title('Evolution of LIN39 in nucleus in LAG2 species');
             
        end
        
    end
    
end

