function plotmRNA(avgHistory, cellName)
%plotmRNA   Plots evolution of total mRNA from OrganismHistory object
%
%   plotmRNA(avgHistory, cellName) will plot the total population of mRNA
%   (top subplot) and protein (bottom subplot) for LIN39, LAG2, EGL17, and 
%   LIP1 by adding concentrations of species throughout the cell stored in 
%   the input avgHistory OrganismHistory object for the cell specified in 
%   cellName.  Each of these species is plotted with a different color on a
%   single figure, with color coding indicated by the figure legend.
%
%   See the GESSA User's Manual for further description of this function. 
%
%   GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%   Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.

     
    species1 = [{'nucleus_mRNA_lin39','cytoplasm_mRNA_lin39','cytoplasm_mRNA_lin39_initiated','cytoplasm_transl_lin39'};...
           {'nucleus_mRNA_lag2','cytoplasm_mRNA_lag2','cytoplasm_mRNA_lag2_initiated','cytoplasm_transl_lag2'};...
           {'nucleus_mRNA_egl17','cytoplasm_mRNA_egl17','cytoplasm_mRNA_egl17_initiated','cytoplasm_transl_egl17'};...
           {'nucleus_mRNA_lip1','cytoplasm_mRNA_lip1','cytoplasm_mRNA_lip1_initiated','cytoplasm_transl_lip1'}];
    species2 = [{'cytoplasm_LIN39','nucleus_LIN39'};...
           {'cytoplasm_LAG2',''};...
           {'cytoplasm_EGL17',''};...
           {'cytoplasm_LIP1',''}];
              
    types = 'TT_Specie';
    legendStrings1 = [{'mRNA lin39'},{'mRNA lag2'},{'mRNA egl17'},{'mRNA lip1'}];
    legendStrings2 = [{'LIN39'},{'LAG2'},{'EGL17'},{'LIP1'}];
     try
       nSpecies = size(species1);
       plotData = [];
       time = [];
       
       for iSpec = 1:nSpecies(1)
           currState = [];
           for i = 1:nSpecies(2)
                [state, time] = avgHistory.getState(cellName, ...
                            types, species1(iSpec,i));
                 if(isempty(currState))
                     currState = state;
                 else
                    currState = currState + state;
                 end
               
           end
           plotData = [plotData,currState];
       end
       subplot(2,1,1); 
       plot(time./3600.,plotData,'.');
       legend(legendStrings1);
       
       nSpecies = size(species2);
       plotData = [];
       time = [];
       
       for iSpec = 1:nSpecies(1)
           currState = [];
           for i = 1:nSpecies(2)
               if (strcmp(species2(iSpec,i),''))
                   continue;
               end;
                [state, time] = avgHistory.getState(cellName, ...
                            types, species2(iSpec,i));
                 if(isempty(currState))
                     currState = state;
                 else
                     currState = currState + state;
                 end
               
           end
           plotData = [plotData,currState];
       end
       subplot(2,1,2);
       plot(time./3600.,plotData,'.');
       legend(legendStrings2,'Location','NorthWest');
 
     catch ME
         outME = addCause( ...
             MException( ...
             'MATLAB:plotmRNA', ...
             'Error in plotting'), ME);
              throw(outME);
     end
end
