function [isType, prot2Type] = findTypes(Proteins, NProteins, TypeName, ...
    NType, multipleMatch)
% function isType(Proteins, NProteins, TypeName, NType, multipleMatch)
%  Determines if each type in TypeName is also in the list of Proteins.
%
%  Input Arguments:
%  (1) Name of proteins in the system
%  (2) Number of proteins in the system
%  (3) Name of other type in the system
%  (4) Number of other types
%  (5) Allows for multiple matches (optional)
% 
%  Output Arguments:
%  (1) NProteins logical vector whose entries are true if TypeName is on
%      the list of proteins and false otherwise.
%  (2) NProteins integer vector whose entries are zero if the protein is
%      not of that type and i if it the ith of that type 
%
%  GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%  Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.

    isType = false(NProteins,1);
    prot2Type = zeros(NProteins, 1, 'uint32');
    
    if (nargin < 5)
        multipleMatch = false;
    end
    
    for iProt = 1:NProteins
        for iType = 1:NType
            typeMatch = isequal(strtok(Proteins(iProt, :)), ...
                strtok(TypeName(iType, :)));
            
            if (typeMatch)
                isType(iProt,1)    = true;
                prot2Type(iProt,1) = iType;
                if (~multipleMatch)
                    return;
                end
            end
            
        end
    end
end
