function isValidDim(type, state)
% function isValidDim(type, state)
%  Checks the dimensions of the input state matches the cell type and
%  throws an error message if they do not match.
%
%  Input Arguments:
%  (1) CellProperties type: description of cell components
%  (2) CellState state:     concentration of cell components
%
%   Return:
%   (none)
%
%   Side Effects:
%   (1) Throws an execption if the input is invalid.
%
%   GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%   Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.


    if (size(state.Proteins, 1) ~= type.NProteins)
        throw(MException(...
            'MATLAB:PBN:Cells:invalidDimensions', ...
            'State has a %d protein types while the cell type has %d', ...
            size(state.Proteins,1), type.NProteins));
    end
    
    if (size(state.ActiveProteins, 1) ~= type.NProteins)
        throw(MException(...
            'MATLAB:PBN:Cells:invalidDimensions', ...
            'State has a %d active protein types while the cell type has %d', ...
            size(state.ActiveProteins,1), type.NProteins));
    end
    
	if (size(state.ExternalSignals, 1) ~= type.NExternalSignals)
        throw(MException(...
            'MATLAB:PBN:Cells:invalidDimensions', ...
            'State has a %d external signal types while the cell type has %d', ...
            size(state.ExternalSignals,1), type.NExternalSignals));
	end
    
	if (size(state.Repressors, 1) ~= type.NRepressors)
        throw(MException(...
            'MATLAB:PBN:Cells:invalidDimensions', ...
            'State has a %d repressor types while the cell type has %d', ...
            size(state.Repressors,1), type.NRepressors));
	end
    
	if (size(state.Scaffolds, 1) ~= type.NScaffolds)
        throw(MException(...
            'MATLAB:PBN:Cells:invalidDimensions', ...
            'State has a %d scaffold types while the cell type has %d', ...
            size(state.Scaffolds,1), type.NScaffolds));
    end

end
