%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% classdef File
%  Defines a file to determine the appropriate reader.
%
%  properties:
%    complete path name of the file
%    file type
%
%  methods:
%    constructor
%    read the file and dump its contents to a variable
%
%  Author:  Elana J. Fertig
%  Date:    13 November 2008
%
classdef File    
    
    properties (GetAccess = public, SetAccess = private)
        name % complete path name of the file
        type % file type (equivalent to extension)
    end
    
    methods
        
        %% File: constructor
        %
        %  Input Arguments:
        %  (1) Complete file name
        %  (2) File type (extension)
        %
        %  Return:
        %  (1) Instantiation of the class File
        %
        function file = File(name, type)
            file.name = char(name);
            file.type = char(type);
        end
        

        %% loadOrganism: initialize an organism from values in a file
        %
        function org = loadOrganism(inFile)
            org = Organism();
            for i = 1:length(inFile)
            switch lower(inFile(i).type)
                case 'mat'
                    org = loadMATOrganism(inFile(i).name);
                case 'xml'
                    loadOrganismXML(org, inFile(i).name);                  
                case 'm'
                    org = eval(inFile(i).name);
                otherwise
                    throw(MException(...
                        'MATLAB:File:invalidType:', ...
                        'Cannot load an organism from %s. %s is an invalid file type.', ...
                        inFile.name, inFile.type));
                end
            end 
        
        end
        
    end
end
