%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


function scaffoldState = defaultInitialScaffoldState(organism)
            
    nScaffTypes = zeros(organism.NCellTypes, 1);
	for iCell = 1:organism.NCellTypes
    	nScaffTypes(iCell,1) = ...
        	organism.CellTypes(iCell).NScaffolds;
	end           
    nScaffolds = max(nScaffTypes);

    if (nScaffolds > 0)
        scaffConc  = zeros(organism.NCells, 1);
        for iCell = 1:organism.NCells
            scaffConc(iCell,1) = max(...
                organism.OrgCells(iCell).State.Scaffolds);
        end
        maxScaffConc = max(scaffConc);
    else
        maxScaffConc = 0;
    end

    
    nProtTypes = zeros(organism.NCellTypes, 1);
	for iCell = 1:organism.NCellTypes
    	nProtTypes(iCell,1) = ...
        	organism.CellTypes(iCell).NProteins;
	end           
    nProteins = max(nProtTypes);
            
    scaffoldState = -ones(maxScaffConc, ...
    	nScaffolds, nProteins, organism.NCells);
end
