%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


function [simulationTimeSteps, outputPopulation] = ...
    simulate(threshold, currSpeciesPopulation, stochRates, ...
    stoichMatrix, stoichCoeffs, delT)
% depending on number of population we call stochastic
% function or ode solver
if (max(currSpeciesPopulation)<threshold)
    % call stochastic simulation
    [simulationTimeSteps, outputPopulation] = ...
        stoch(currSpeciesPopulation, stochRates, ...
        stoichMatrix, stoichCoeffs, delT);
else
    % ODE Construction
    M1s = ones(size(stochRates));
    cme_function = @(t,x) stoichMatrix*(stochRates.*prod(x(:,M1s).^stoichCoeffs)).';
    [simulationTimeSteps, outputPopulation] = ...
        ode15s(cme_function, [0 delT], ...
        currSpeciesPopulation);
    outputPopulation = round(outputPopulation');
    simulationTimeSteps = simulationTimeSteps';
end % if
end % function simulate
