%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


function avgHistory = computeAverage(orgHistory, nOrganism, startTime, ...
    endTime, timeStep, avgStep)
% compute average organism from orgHistory
% takes every avgStep timestamp
    try
        if (nargin < 6)
            histTimeStep =  startTime:timeStep:endTime;
        else
            histTimeStep = startTime:avgStep:endTime;
        end

        avgHistory = OrganismHistory(orgHistory(1,1));
        if (nOrganism > 1)
            for iOrganism = 2:nOrganism
                avgHistory = sumSetTimes(avgHistory,orgHistory(iOrganism,1),histTimeStep);
            end
            avgHistory = avgHistory.*(1./double(nOrganism));
        end
    catch ME
        outME = addCause( ...
            MException( ...
            'MATLAB:computeAverage', ...
            'Error in averaging of organisms.'), ...
            ME);
        throw(outME);
    end
end
