%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.



function [ NOrganism, NMolecules ] = computeNumberOfSpecies( orgHistory, cellName, ...
    speciesName, speciesType, timeStep, fileName)
    % count number of organisms with species speciesName in cellName cells
    % and maximum number of molecules
    % orgHistory is history for all organisms
   
    if (nargin < 5)
        timeStep = 1;
    end
    
    NCells = length(cellName);
    NOrganism = zeros(1,NCells);
    NMolecules = zeros(1,NCells);
           
     try
         nOrg = size(orgHistory);
         for iCell = 1:NCells
            % index of cellName cell
            cellIndex = findType(cellName(iCell),orgHistory(1,1).cellNames);
            % index of species in array specified by speciesType
            index = findType(char(speciesName), ...
                   orgHistory(1,1).cellTypes(cellIndex).getStateNames(speciesType));
            if (iCell > 0 && ~isempty(index))
                for iOrganism = 1:nOrg(1,1)
                    % check the number of species in specified cell
                    s = size(orgHistory(iOrganism,1).orgCellTracker);
                    hasAnyMolecules = 0;
                    for i = 1:timeStep:s(1,2)
                        % get array with number of molecules specified by speciesType
                        state = orgHistory(iOrganism,1).orgCellTracker(cellIndex,i).getState(speciesType);

                        if (~isempty(state))
                            mol = 0;
                            if (~isa(state,'cell'))
                                mol = state(index,1);
                            else
                                mol = state{index(1)}(index(2));
                            end
                            if (mol >0)
                                hasAnyMolecules = 1;
                                if(NMolecules(1,iCell) < mol);
                                    NMolecules(1,iCell) = mol;
                                end
                            end
                        end
                    end
                 end
                 NOrganism(1,iCell) = NOrganism(1,iCell) + hasAnyMolecules; 
             end
           
            % print results
             fprintf('Number of organisms with %s in cell %s is %d of %d\n', ...
                    speciesName, char(cellName(iCell)), NOrganism(1,iCell), nOrg(1,1));
             fprintf('Maximum number of %s in cell %s is %d\n', ...
                 speciesName, char(cellName(iCell)), NMolecules(1,iCell));
         end
         % if name of file is specified
         if (nargin == 6)
            fileNameTXTTable = [fileName '_table.txt'];
            fileNameTXT = [fileName '.txt'];
            fileNameMat = [fileName '.mat'];
             %save(fileNameMat,  'NOrganism', 'NMolecules');
             fid = fopen(fileNameTXTTable, 'wt');
                fprintf(fid,'\t\t');
                for iCell = 1:NCells
                    fprintf(fid,'%s\t', char(cellName(iCell)));
                end
                fprintf(fid, '\n');
                fprintf(fid, '# orgs\t');
                fprintf(fid, '%d\t', NOrganism);
                fprintf(fid, '\n');
                fprintf(fid, '# %s\t', speciesName);
                fprintf(fid, '%d\t', NMolecules);                       
             fclose(fid);
             fid = fopen(fileNameTXT, 'wt');
                for iCell = 1:NCells
                    fprintf(fid, 'Number of organisms with %s in cell %s is %d of %d\n', ...
                        speciesName, char(cellName(iCell)), NOrganism(1,iCell), nOrg(1,1));
                    fprintf(fid, 'Maximum number of %s in cell %s is %d\n', ...
                     speciesName, char(cellName(iCell)), NMolecules(1,iCell));
                end
            fclose(fid);
         end
         catch ME
              outME = addCause( ...
                  MException( ...
                      'MATLAB:computeNumberOfSpecies', ...
                      'Error in counting number of species.'), ME);
              throw(outME);
     end
     

end
