function [avgHistory, allOrgHistory, output, startTime, endTime] = ...
    driveHybridModel(simulationParameterFile, saveHistFile)
% driveHybridModel  Central driver function for GESSA 
%
%   driveHybridModel(simulationParameterFile) will run GESSA for
%   the organism and simulation specifications provided in the input
%   argument simulationParameterFile.
%
%   output arguments:
%       avgHistory: Average OrganismHistory over all organism simulations
%       allOrgHIstory: OrganismHistory for each organism simulation
%       output: Name of output archive of simulation results
%
%   See the GESSA User's Manual for further description about the
%   required format of input files and output of this function.
%
%   GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%   Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.


% load input files and parameters of simulation
[OrganismFile, PPIFile, TTFile, DiffusionFile, output,...
 startTime, endTime, nOrganism, timeStep, avgTimeStep] = ...
    loadParameters(simulationParameterFile);

% run simulation
[avgHistory, allOrgHistory] = simulateOrganisms(nOrganism, OrganismFile, ...
    [PPIFile, TTFile, DiffusionFile], ...
    startTime, timeStep, endTime, avgTimeStep);

% save results to matlab archive
resultsDir = fullfile(output,'SimulationResults');
configDir = fullfile(output,'ConfigurationFiles');

mkdir(output);
mkdir(resultsDir);
mkdir(configDir);

if (nargin >= 2)
   if (saveHistFile ~= false && ~strcmpi(saveHistFile, 'false') && ...
       ~isempty(strtrim(saveHistFile)) )
      save(fullfile(resultsDir, saveHistFile), 'avgHistory', 'allOrgHistory');
   end
end
 
allInputFiles = [OrganismFile,PPIFile,TTFile,DiffusionFile];
% check that all files is not 'none'
filesForArchive = [];
for i = 1:length(allInputFiles)
    if (~strcmp(allInputFiles(i).name,'none'))
        copyfile(allInputFiles(i).name, configDir);
    end
end
copyfile(simulationParameterFile, configDir);

% save input files and results in archive
zip(output,fullfile(output,'*'));

rmdir(output, 's');

end


