%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%
% indicies = findType(string, list)
%  Finds which rows of the list of strings matches the input string.
%
%  Input Arguments:
%  (1) list of strings to find in the list
%  (2) list of strings from which to find the specified strings
%
%  Return:
%  (1) Rows in the list containing the desired input string.  
%  Returns -1, if no matching strings were found
%
%  Author:  Elana J. Fertig
%  Date:    26 November 2008
%  Version: $ID$
%
% History
% 23May2010 LD Remove MExeption and add -1 as result if on matching were
% found


function indicies = findType(charInList, ListNames)
    toFind = char(charInList);
    indicies = uint8.empty;
    % if ListNames is not cell vector
    if (~isa(ListNames,'cell'))
        list = char(ListNames);
       
        for iSearch = 1:size(list,1)
            for jSearch = 1:size(toFind,1)
                if (strcmpi(strtok(toFind(jSearch, :)), strtok(list(iSearch, :))))
                    indicies = [indicies, iSearch];
                    break;
                end
            end
        end
    % if ListNames is cell vector (for TT_Species)  
    % indices is a 2D martix: the 1st row is column index in ListNames
    % the 2d row is index of charInList string in the the corresponding 
    % column of ListNames
    else
        for iList = 1: size(ListNames,2)
           list = char(ListNames{:,iList});
            for iSearch = 1:size(list,1)
                for jSearch = 1:size(toFind,1)
                    if (strcmpi(strtok(toFind(jSearch, :)), strtok(list(iSearch, :))))
                        indicies = [indicies, [iList; iSearch]];
                        break;
                    end
                end
            end
        end
    end
    
%     if (isempty(indicies))
%         indicies = -1;
%         throw( MException(...
%             'MATLAB:findType:noneFound', ...
%             'Did not find %s in the specified list.', ...
%             toFind) );
%    end
end
