%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% propType = getCellPropertyByName(prop)
%  Identifies the cell property desired.
%
%  Input Arguments:
%  (1) string describing the cell property
%
%  Return:
%  (1) standardized string describing the cell property for easy recovery
%
%  Throws:
%  (1) MException if no matching cell properties
%
%  Author:  Elana J. Fertig
%  Date:    26 November 2008
%  Version: $ID$
%
function cellPropertyType = getCellPropertyByName(prop)
    switch lower(char(prop))
        case {'prot', 'protein', 'proteins', 'prots'}
            cellPropertyType = char('Protein');
        case {'activeprotein', 'actprot', 'activeprot', 'activeprots', ...
              'activeproteins', 'actprots'}
            cellPropertyType = char('ActiveProtein');
        case {'activator', 'activators', 'signal', 'signals', ...
              'externalsignal', 'externalsignals', 'extsig', 'extsigs', ...
              'externalsig', 'externalsigs', 'extsignal', 'extsignals'}
            cellPropertyType = char('ExternalSignal');
        case {'repressor', 'repr', 'repressors', 'reprs'}
            cellPropertyType = char('Repressor');
        case {'scaffold', 'scaff', 'scaffolds', 'scaffs'}
            cellPropertyType = char('Scaffold');
        case {'transcriptionfactor', 'tf', 'tfs', 'transfactor', ...
              'transcriptionfactors', 'transfactors'}
            cellPropertyType = char('TF');
        case {'tt','tt_specie','tt_species'}
            cellPropertyType = char('TT_Specie');  
        case {'receptor', 'receptors', 'recpt'}
            cellPropertyType = char('Receptor');
        case {'actrecept', 'actreceptors', 'activereceptor', ...
                'activereceptors'}
            cellPropertyType = char('ActiveReceptor');
        case {'neighbor', 'neighborsignal', 'neighbors', ...
                'neighborsig', 'neighborsigs'}
            cellPropertyType = char('NeighborSignal');
        case {'transport', 'transportedproteins', 'transported', ...
                'transportprot', 'tranportprotein', 'transportproteins'}
            cellPropertyType = char('TransportProtein');
        otherwise
            throw( MException(...
                'MATLAB:getCellPropertyByName:noneFound', ...
                '%s does not match any cell properties', ...
                char(prop)) );
    end
end
