function nMol = getSpeciesNumber(orgHistory, speciesName, speciesType, ...
    cellName, timeStamp)
% getSpeciesNumber     Extracts species population from OrganismHistory object
%
%   getSpeciesNumber(orgHistory, speciesName, speciesType, cellName, timeStamp)
%   will return the population of species called speciesName of type
%   speciesType from the OrganismHistory object for cell(s) in  cellName at 
%   the time given by timeStamp.
%
%   See the GESSA User's Manual for further description of this function
%   
%   GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%   Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%   This program is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program.  If not, see <http://www.gnu.org/licenses/>.


    NCells = length(cellName);
    nMol = zeros(1, NCells);
    s = size(orgHistory.orgCellTracker);
    timeIndex = 0;
    index = 0;
        
    % find index for timeStamp
    for i = 1:s(1,2)-1
        if (orgHistory.timeTracker(1,i)<timeStamp &&...
                orgHistory.timeTracker(1,i+1)>=timeStamp)
            timeIndex = i+1;
            break;
        end
    end
    
    for iCell = 1:NCells
        % index of cellName cell
        cellIndex = findType(char(cellName(iCell)),orgHistory.cellNames);
        % index of species in array specified by speciesType
        index = findType(char(speciesName), ...
            orgHistory.cellTypes(cellIndex).getStateNames(speciesType));
        if (iCell > 0 && timeIndex > 0 && ~isempty(index))
            % get array with number of molecules specified by speciesType
            state = orgHistory.orgCellTracker(cellIndex,...
                timeIndex).getState(speciesType);
            
            if (~isempty(state))
                nMol(1,cellIndex) = state{index(1)}(index(2));
            end
        end
    end
end
