%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% reads txt file with input files (model files, files for initiation of updaters) 
% and input parameters (time of simulation start and end, 
% number of organisms, and time steps for each updater), and name for
% output archive 

function [ modelFiles, PPIFile, TTFile, DiffFile, output...
    startTime, endTime, nOrganism, Timesteps, avgStep ] = ...
    loadParameters( file )
try
    % load file
    fid = fopen(file);
    C_text = textscan(fid, '%s', 'delimiter', '\t');
    fclose(fid);
    parameters = C_text{1};
catch ME
    fprintf('loadParameters:invalid file. Invalid input file: %s \n', file);
    outME = addCause( ...
        MException( ...
        'MATLAB:loadParameters:invalid file', ...
        'Invalid input file: %s', file), ...
        ME);
    error('Failed to read file %s.',file);
    throw(outME);
end
    PPItimestep = 0;
    TTtimestep = 0;
    Difftimestep = 0;
    modelFiles=[];
    PPIFile = [];
    TTFile = [];
    DiffFile =[];
    output ='';
    nOrganism = 1;
    
    % get files and parameters by their names
    i=1;
try
    while i <= length(parameters)
        
        switch lower(strtok(char(parameters(i))))
            case 'modelfile'
                infile = char(parameters(i+1));
                ext = getExtension(infile);
                modelFiles = [modelFiles,File(infile,ext)];
                i = i+1;
            case 'ppiinitfile'
                infile = char(parameters(i+1));
                ext = getExtension(infile);
                PPIFile = [PPIFile,File(infile,ext)];
                i = i+1;
            case 'ttinitfile'
                infile = char(parameters(i+1));
                ext = getExtension(infile);
                TTFile = [TTFile,File(infile,ext)];
                i = i+1;
            case 'diffusioninitfile'
                infile = char(parameters(i+1));
                ext = getExtension(infile);
                DiffFile = [DiffFile,File(infile,ext)];
                i = i+1;
            case 'outputarchive'
                output = char(parameters(i+1));
                i = i+1;
            case 'simulationstarttime'
                startTime = str2double(parameters(i+1));
                i = i+1;
            case 'simulationendtime'
                endTime = str2double(parameters(i+1));
                i = i+1;
            case 'numberoforganisms'
                nOrganism = str2double(parameters(i+1));
                i = i+1;
            case 'timestepppi'
                PPItimestep = str2double(parameters(i+1));
                i = i+1;
            case 'timesteptt'
                TTtimestep = str2double(parameters(i+1));
                i = i+1;
            case 'timestepdiffusion'
                Difftimestep = str2double(parameters(i+1));
                i = i+1;
            case 'timestepaverage'
                avgStep = str2double(parameters(i+1));
                i = i+1;
        end % switch
        i=i+1;
    end % while
    Timesteps = [PPItimestep, TTtimestep, Difftimestep];
    % if there is no file with model description, throw an error
    if (isempty(modelFiles))
        throw(MException( ...
        'MATLAB:loadParameters:There is no file with model description in the central configuration file %s', ...
        file));
    end
    % check if file is empty, create empty File object
    if (isempty(PPIFile))
        PPIFile = File('none','none');
    end
    if (isempty(TTFile))
        TTFile = File('none','none');
    end
    if (isempty(DiffFile))
        DiffFile = File('none','none');
    end
   
catch ME
    fprintf('loadParameters: Error in parsing data from file %s \n', file);
    outME = addCause( ...
        MException( ...
        'MATLAB:loadParameters:invalid data', ...
        'Error in parsing data from file %s', file), ...
        ME);
    error('Failed to parse data from file %s.',file);
    throw(outME);
end

end
% returns file extension from a path
function ext = getExtension(path)
ext = '';
% split string by dot
    s = regexp(path,'\.','split');
    % if string was not splitted
    if (length(s) == 1)
        fprintf('loadParameters: Can not get extension from the %s path', path);
        return;
    end
    if (length(s) > 1)
        % return last element in vector
        ext = s(length(s));
    end
end

