%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


function speciesTimeTable = numberOrgsHist( orgHistory, cellName, ...
    speciesName, speciesType, speciesAmount, startTime, endTime, timeStep, fileName)
    % count number of organisms with specified amount of species speciesName 
    % at time points that specified of timeStep in cellName cells
    % orgHistory is history for all organisms
   
    if (nargin < 8)
        timeStep = 10;
        fileName = 'orgHist.txt';
    end
    if (nargin < 9)
        fileName = 'orgHist.txt';
    end
    
    NCells = length(cellName);
    snapshots = (startTime+timeStep):timeStep:endTime;
    snapshots = snapshots/3600;
               
    try
        % find indexes of cells
        cellIndex = zeros(NCells,1);
        for iCell = 1:NCells
                % index of cellName cell
                cellIndex(iCell,1) = findType(cellName(iCell),orgHistory(1,1).cellNames);
        end
        
        % time when signal appears in the cell
        signalTimePerCell = NaN(NCells,1);
        
        for iCell = 1:NCells
                % index of sinal in externalSignal vector
             signalIndex = findType('LIN3', ...
                    orgHistory(1,1).cellTypes(cellIndex(iCell,1)).getStateNames('extsig'));
            s = size(orgHistory(1,1).orgCellTracker);

            for i = 1:s(1,2)
               state = orgHistory(1,1).orgCellTracker(cellIndex(iCell,1),i).getState('extsig');
               if (~isempty(state)&& round(state(signalIndex,1))>0)
                     signalTimePerCell(iCell,1) = orgHistory(1,1).timeTracker(i);
                     break;
                end
            end
        end
        
       % index of species in array specified by speciesType
        nOrg = size(orgHistory);
        speciesTimeTable = NaN(nOrg(1,1),NCells);
        
        for iOrg = 1:nOrg(1,1)
             % check the number of species in specified cell
             s = size(orgHistory(iOrg,1).orgCellTracker);
                   
            for iCell = 1:NCells
              index = findType(char(speciesName), ...
                    orgHistory(1,1).cellTypes(cellIndex(iCell,1)).getStateNames(speciesType));
                
       
                if (iCell > 0 && ~isempty(index))
                    for i = 1:s(1,2)
                        % get array with number of molecules specified by speciesType
                        state = orgHistory(iOrg,1).orgCellTracker(cellIndex(iCell,1),i).getState(speciesType);
                        % check the number of species
                        % and store the time when it appears
                        if (~isempty(state))
                            if ((~isa(state,'cell') && state(index,1)>= speciesAmount)|| ...
                                 (isa(state,'cell') && state{index(1)}(index(2))>= speciesAmount))
                                speciesTimeTable(iOrg,iCell) = ...
                                    orgHistory(iOrg,1).timeTracker(i);
                            end
                            break;
                        end
                    end
                end
            end
        end
        % convert results into hours  
        speciesTimeTable = speciesTimeTable./3600;
        signalTimePerCell = signalTimePerCell./3600;
        
        % store results into file
         fid = fopen(fileName, 'wt');
         fprintf(fid, '%s = %d\n', char(speciesName), speciesAmount);
         fprintf(fid, 'org #\t');         
         for iCell = 1:NCells
             fprintf(fid,'%s\t', char(cellName(iCell)));
         end
        fprintf(fid, '\n');               
        for iOrg = 1:nOrg(1,1)
             fprintf(fid, '%d\t\t', iOrg);  
              for iCell = 1:NCells
                fprintf(fid,'%3.1f\t', speciesTimeTable(iOrg,iCell));
              end
              fprintf(fid, '\n');               
        end
        fclose(fid);
        
       % create histogram for each cell separately
        for iCell = 1:NCells
            figure;
            [n, xout]=hist(speciesTimeTable(:,iCell));
            hold on;
            axis([startTime/3600, endTime/3600,min(n),max(n)+0.5]);
            str = strcat(speciesName, {' >= '}, int2str(speciesAmount), {' in cell '}, cellName(iCell));
            title(str);
            xlabel('time');
            ylabel('# organisms');
            hist(speciesTimeTable(:,iCell));
            plot(ones(size(min(n):max(n)+1))*signalTimePerCell(iCell,1),min(n):max(n)+1, 'r')
            hold off;
        end;
        
     
         catch ME
              outME = addCause( ...
                  MException( ...
                      'MATLAB:numberOrgsHist', ...
                      'Error in counting number of organisms for histogram.'), ME);
                  throw(outME);
     end
     

end
