%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% simulate the set of organisms
function [avgHistory, orgHistory] = simulateOrganisms(nOrganism, ...
    organismFile, initFiles, startTime, timeStep, endTime, avgTimeStep)

    outputCopyright();

    orgHistory = repmat(OrganismHistory, nOrganism, 1); % log state for each simulation
   
    parfor iOrganism = 1:nOrganism
        
        fprintf('Simulating organism %d of %d\n', iOrganism, nOrganism);
        sim = Simulator([true, true, true]); % (specified whether to do PPI, TT, diffusion)
        sim.initializer(organismFile.loadOrganism(), initFiles, startTime);
        orgHistory(iOrganism,1) = sim.simulateAllTime(timeStep, endTime);
        
       % clear sim;

    end
    
    fprintf('Computing average state with step %d\n', avgTimeStep);
    avgHistory = computeAverage(orgHistory, nOrganism, startTime, endTime,...
        timeStep, avgTimeStep);
end
