%    GESSA (Graphically Extended Stochastic Simulation Algorithm)
%   
%    Copyright (C) 2010 Michael Ochs, Elana Fertig, Ludmila Danilova
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


classdef Protein < handle
    % represents a protein (species) from SBML format
    %  Author:  Ludmila Danilova
    %  Date:    18 November 2008
    %  
    % History
    % 
    % 05Jan09  LD  Add compartment property
    % 10Feb10  LD  Add active and inactive concentration
    
    properties
        name = '';        % name of protein
        type = '';        % type of protein (activator, repressor, etc.)
        compartment = ''; % compartment
        amountActive = 0; % concentration of active protein
        amountInactive = 0; % concentration of inactive protein
        activates = {};   % list of proteins which are activated by this protein
        represses = {};   % list of proteins which are repressed by this protein
        binds = {};       % list of proteins which are binded with this protein
        scaffolds = {};   % list of scaffolded proteins 
    end
    
    methods 
        %% Constructor
      function new_protein = Protein(inputName)
        if (nargin > 0)
            % specify property 'name'
           new_protein.name = inputName;  
        end
      end
    end
end
